==> www_authenticate-1.0.1.tar.gz: www_authenticate/src/WwwAuthenticateSubscriber.php <==
<?php
/**
 * @file
 * Contains \Drupal\www_authenticate\WwwAuthenticateSubscriber.
 */
namespace Drupal\www_authenticate;

use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\HttpKernel\Event;
use Symfony\Component\HttpKernel\Event\GetResponseEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Provides a WwwAuthenticateSubscriber.
 */
class WwwAuthenticateSubscriber implements EventSubscriberInterface {
  /**
   * // only if KernelEvents::REQUEST !!!
   * @see Symfony\Component\HttpKernel\KernelEvents for details
   *
   * @param \Symfony\Component\HttpKernel\Event\GetResponseEvent $event
   *   The Event to process.
   */
  public function WwwAuthenticateLoad(GetResponseEvent $event) {

    // Get config.
    $config = \Drupal::config('www_authenticate.config');
    // Do nothing if disabled.
    if (!$config->get('enabled')) {
      return;
    }

    // Retrieve the user and pass from config.
    $user = $config->get('login');
    $pass = $config->get('password');

    // Test basic auth credentials.
    if (!empty($_SERVER['PHP_AUTH_USER'])
      && isset($_SERVER['PHP_AUTH_PW'])
      && $_SERVER['PHP_AUTH_USER'] === $user
      && $_SERVER['PHP_AUTH_PW']   === $pass
    ) {
      // Authentication passes, do nothing.
      return;
  } else {

      // Authentication failed, print the authorization headers and end the request.
    $print = $config->get('message');
    $sitename = \Drupal::config('system.site')->get('name');

    header(sprintf('WWW-Authenticate: Basic realm="%s"', $sitename));
    header('HTTP/1.0 401 Unauthorized');

    die($print);

    exit;
  }
}

  /**
   * {@inheritdoc}
   */
  static function getSubscribedEvents() {
    // Add WwwAuthenticateLoad as a subscriber to the request event.
    // $events[KernelEvents::REQUEST][] = array('WwwAuthenticateLoad', 20);
    $events[KernelEvents::REQUEST][] = array('WwwAuthenticateLoad');
    return $events;
  }
}

==> www_authenticate-1.0.3.tar.gz: www_authenticate/src/WwwAuthenticateSubscriber.php <==
<?php
/**
 * @file
 * Contains \Drupal\www_authenticate\WwwAuthenticateSubscriber.
 */
namespace Drupal\www_authenticate;

use Symfony\Component\HttpKernel\Event\RequestEvent;
use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\HttpKernel\Event;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Provides a WwwAuthenticateSubscriber.
 */
class WwwAuthenticateSubscriber implements EventSubscriberInterface {
  /**
   * // only if KernelEvents::REQUEST !!!
   * @see Symfony\Component\HttpKernel\KernelEvents for details
   *
   * @param \Symfony\Component\HttpKernel\Event\RequestEvent $event
   *   The Event to process.
   */
  public function WwwAuthenticateLoad(RequestEvent $event) {

    // Get config.
    $config = \Drupal::config('www_authenticate.config');
    // Do nothing if disabled.
    if (!$config->get('enabled')) {
      return;
    }

    // Retrieve the user and pass from config.
    $user = $config->get('login');
    $pass = $config->get('password');

    // Test basic auth credentials.
    if (!empty($_SERVER['PHP_AUTH_USER'])
      && isset($_SERVER['PHP_AUTH_PW'])
      && $_SERVER['PHP_AUTH_USER'] === $user
      && $_SERVER['PHP_AUTH_PW']   === $pass
    ) {
      // Authentication passes, do nothing.
      return;
  } else {

      // Authentication failed, print the authorization headers and end the request.
    $print = $config->get('message');
    $sitename = \Drupal::config('system.site')->get('name');

    header(sprintf('WWW-Authenticate: Basic realm="%s"', $sitename));
    header('HTTP/1.0 401 Unauthorized');

    die($print);

    exit;
  }
}

  /**
   * {@inheritdoc}
   */
  static function getSubscribedEvents() {
    // Add WwwAuthenticateLoad as a subscriber to the request event.
    // $events[KernelEvents::REQUEST][] = array('WwwAuthenticateLoad', 20);
    $events[KernelEvents::REQUEST][] = array('WwwAuthenticateLoad');
    return $events;
  }
}
